---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--  Copyright (c) 2003 Pete Spicer
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
text = [[
            KONTROLLER

RÖRELSE:

Det här spelet kontrolleras med musen. Vänsterklicka på en plats dit du vill gå. Håll nere knappen för att fortsätta gå i den riktningen. Håll nere CTRL för att springa.

ATTACK:

Vänsterklicka på en fiende för att Tux ska gå nära och attackera den med det vapen som används. Om det är ett skjutvapen kommer Tux stå stilla och skjuta mot fienden.

SPECIALFUNKTIONER:

Högerklicka för att använda vald förmåga/program.

Standardtangenter (de flesta kan ändras via tangentlistan i spelet - F1)

  Esc ... Visa huvudmenyn
  F1 ... Visa tangentlista
  F2 ... Helskärmsläge (endast Linux)
  F3 ... Snabbspara
  F4 ... Snabbladda
  F5-F12 ... Snabbgenväg till program (1-8)

  I ... Panelen Förråd (Inventory)
  C ... Panelen Karaktär (Character)
  S ... Panelen Förmågor/Program (Skills)
  Mellanslag ... Stäng alla paneler
  Q ... Uppdragslogg
  0-9 ... Använd föremålen i snabbförrådet (0-9)

  P ... Pausa
  Håll in A ... Attackera medan du står på samma ställe
  Håll in Shift ... Fortsätt sikta på nuvarande mål när du springer
  Tab ... Visa/dölj autokartan

  R ... Ladda om vapen
  Håll in Ctrl ... Spring
  U ... Spring alltid på/av

  Håll in X ... Visa etiketter över föremål på marken
  Z ... Visa alltid etiketter över föremål på/av
  T ... Gör väggar genomskinliga i närheten av Tux (endast OpenGL)

TA ÖVER/PRATA

För att prata med en vänlig droid, klickar du på den. För att ta över en fientlig bott, välj hackning i panelen förmågor och högerklicka på botten för att börja ta över.

I övertagningsspelet kan du använda mushjulet eller piltangenterna.

Du kanske vill spela Handledningen som du hittar i huvudmenyn.

Om du fastnar och behöver hjälp, tveka inte att gå till #freedroid på irc.libera.chat och fråga om hjälp.

Det var allt, ha det så roligt med spelet.



Vänsterklicka för att börja spela.
]]
}
