---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "HellFortressTwo.ogg",
voice_acting = "GameLost.ogg",
preroll_text = 3,
postroll_text = 3,
text = [[
            Juego Perdido

Por favor intentalo de nuevo, y cuando lo hagas, asegurate de comprar de nuestros patrocinadores:

Dr. How - "¡Tecnología altamente conveniente!"

F4rm4cia C4n4diense - "¡R3medios herbarios de increíble progreso! ¡¡¡Satisfacción 100% garantiz4da!!!"

Soluciones Criónicas - "¡Tome el viaje mas rápido hacia el futuro con Soluciones Criónicas!"

Balística Futura - "Mas haya de la balística. Balística Futura."

MegaSystems - "¿Que es lo que no quieres hacer hoy?"

Eliminación de Basura Masternak - "APLASTAMOS tu BASURA."

Compañía Nicholson - "Seguridad con venganza."

Sol Rojo - "La noche se acabo: ¡saborea el amanecer!"



Por favor inténtelo de nuevo. Pulse para continuar.
]]
}
