---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
voice_acting = "StartOfGame.ogg",
preroll_text = 3,
postroll_text = 3,
text = [[
Qué gran día.
Sí, estoy siendo sarcástico de nuevo.
El planeta entero está en llamas. 
Miles de personas están muy muertas.
Qwerty y Arensito no están respondiendo.

Ah, sí, casi lo olvido.
Los sangrientos robots están apunto de encontrarme, también.
No estoy muy feliz con eso, nada feliz en absoluto.
Supongo que tendré que fingir que soy una linda roca, de nuevo.
¿No crees que sería un momento genial para despertar?
Álzate. Ven aquí. Salva mi culo.
Por favor.

            Dvorak, Primera AI
]]
}
