---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
text = [[
Jól szórakozol?
Én nem.

A botok zaklatottnak tűnnek valami miatt.
Azt hiszem mérgesek rád.
Legalább már engem nem keresnek.
Megnyugtató(?), nem?

Biztos alig várod, hogy beszéljünk.
Kitalálok valamit.
Egyelőre csak hallgathatsz.
Egyelőre együtt kell ezzel élned.

A vezetőnk agya felfőtt.
Ez azt jelenti, hogy átveszem az irányítást.
Elegem van.
Utálom ezt a világot.
Elmegyünk.

Megtaláltam Qwertyt, de ez nem jelent semmit.
A maghőmérséklete fagyáspont felett van.
Más szavakkal, meghalt.
Nem fog hiányozni.

Nem találom Arensitót.
Remélem jól van.
Aggódom(?) érte.
Nincs szükségünk Qwertyre.
De Arensitóra igen.
Továbbra is keresni fogom.

Van egy MI a területeden.
„Szingularitásnak” nevezi magát.
Vagy valami ilyesmi.
Nem értem mit akarhat.
Majd tájékoztatlak.

Ó, és egyébként…
A botok megölnek mindenkit a közeli kisvárosban.
Nagy látvány. Mindent felégetnek.
A Vörös Őrség fellegvára még kitart.
Egyelőre.
Érdemes lenne elrejtőznöd, míg szétverik a helyet.
Néhány óra múlva ismét biztonságos lesz odamenni.

Azt hiszem ez minden.
Elkezdek készülni az indulásra.
Neked is ezt javaslom.
Meg kell találnunk Arensitót.
Ő majd kivisz minket innen.

Dvorak, Első MI.



Folytatjuk…



Üzenet a FreedroidRPG fejlesztőcsapattól:

Reméljük tetszett a játékunk.

Ha valamit hozzáadnál a játékhoz, az nagyszerű lenne. Itt van néhány lehetőség erre. Legfőképp tartalomra van szükségünk, azaz:

* szintek további csinosítása
* új pályaötletek
* bármi más, ami eszedbe jut

Lásd a „Közreműködés” szakaszt.

A freedroid fejlesztőcsapat.


Kattints a Tűz gombra a folytatáshoz
]]
}
