--[[
  Copyright (c) 2003 Johannes Prix

  This file is part of Freedroid

  Freedroid is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  Freedroid is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Freedroid; see the file COPYING. If not, write to the 
  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
  MA  02111-1307  USA
]]--

-- Feel free to make any modifications you like.  If you set up 
-- something cool, please send your file in to the Freedroid project.

mission_list {
{
	mission_name = _"Where Am I?",
	mission_description = "Locate yourself in these bland lands, after a crash.",
},
{
	mission_name = _"Message From An Old Friend",
	mission_description = "Retrieve Dvorak's message.",
},
{
	mission_name = _"The Reapers Of MegaSys I",
	mission_description = "Find and defeat The Glitch.",
},

}
