---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--  Copyright (c) 2003 Pete Spicer
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
text = [[
            CONTROLS

MOVEMENT:

The game is controlled using the mouse. Left click onto the locations you want to move to.  Hold the button down to keep moving in that direction.  Holding down CTRL key will make you run.

ATTACK:

Left clicking an enemy will cause Tux to come close to the bot and to start attacking it with the current weapon. If the current weapon is a gun then Tux will stand still and shoot the bot.

SPECIAL FUNCTIONS:

Use the right click to activate the currently selected skill/program.

Default keys (most keys can be reassigned with the ingame key chart - F1)

  Escape     ... Show main menu
  F1         ... Show keychart
  F2         ... Toggle fullscreen (Linux only)
  F3         ... Quicksave
  F4         ... Quickload
  F5-F12     ... Quick-select program 1 through 8

  I          ... Inventory panel
  C          ... Character panel
  S          ... Skills/Program panel
  Space      ... Close all open panels
  Q          ... Quest log
  0-9        ... Use quick-inventory items 0-9

  P          ... Pause
  Hold A     ... Attack while staying at the same position
  Hold Shift ... Keep current target selected when moving
  Tab        ... Toggle automap

  R          ... Reload weapon
  Hold Ctrl  ... Run
  U          ... Toggle always run

  Hold X     ... Show labels for items on the ground
  Z          ... Toggle show labels for items on the ground
  T          ... Toggle walls becoming transparent when Tux approaches (OpenGL only)

TAKEOVER/CHAT

To chat with a friendly droid, it's enough to click on it.  To take over a hostile bot, select the takeover/chat skill from the skills screen, then click the right mouse button to initiate takeover.

For the takeover game, you can use the mouse wheel or the cursor keys.

You may be interested in playing the Tutorial which you can access from the main menu.

If you are stuck and need help, feel free to come to #freedroid on irc.libera.chat and ask for help.

That is all, have a nice game.



Press left mouse button to start playing.
]]
}

