---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--  Copyright (c) 2003 Pete Spicer
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
text = [[
            УПРАВЛЕНИЕ

ДВИЖЕНИЕ:

Игра управляется при помощи мыши. Щёлкайте левой кнопкой места, куда хотите переместиться. Зажатая кнопка позволяет двигаться в выбранном направлении. Удерживаемая нажатой клавиша CTRL позволит вам бежать.

АТАКА:

По щелчку левой кнопкой мыши на враге Такс приблизится к боту и атакует его текущим оружием. Если текущее оружие — пушка, тогда Такс останется на месте и выстрелит в бота.

СПЕЦИАЛЬНЫЕ ФУНКЦИИ:

Щелчок правой кнопкой мыши активирует выбранное умение или программу.

Клавиши по умолчанию (большинство может быть переназначено в меню горячих клавиш — F1)

  Escape     ... Главное меню
  F1         ... Горячие клавиши
  F2         ... Полноэкранный режим (только в Linux)
  F3         ... Быстрое сохранение
  F4         ... Загрузка быстрого сохранения
  F5-F12     ... Быстрый выбор из восьми программ

  I          ... Инвентарь
  C          ... Панель характеристик
  S          ... Панель умений/программ
  Пробел      ... Закрыть все открытые панели
  Q          ... Журнал заданий
  0—9        ... Слоты 0—9 для быстрого вызова из инвентаря

  P ... Пауза
  (Удерживая) A     ... Атаковать, оставаясь на той же позиции
  (Удерживая) Shift ... Сохранять выбранную цель при движении
  Tab        ... Автокарта

  R ... Перезарядить оружие
  (Удерживая) Ctrl ... Бег
  U ... Переключить режим постоянного бега.

  (Удерживая) X ... Показать имена предметов на земле
  Z ... Переключить режим показа имён предметов на земле
  T          ... Прозрачность стен при приближении Такса (только для OpenGL)

ВЗЛОМ/ЧАТ

Для разговора с дружественным дроидом достаточно щёлкнуть по нему. Для взлома враждебного бота, выберите «Взлом» в панели умений, затем щёлкните цель правой кнопкой мыши.

Во время взлома вы можете использовать колесо мыши или клавиши курсора.

Возможно, вас заинтересует учебная игра, доступная из главного меню.

Если вы застряли и нужна помощь, не стесняйтесь попросить о ней во #freedroid на irc.libera.chat.

Вот и всё, приятной игры.



Нажмите левую кнопку мыши для начала игры.
]]
}
