---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
voice_acting = "EndOfAct.ogg",
preroll_text = 2,
postroll_text = 5,
text = [[
    Har du kul?
  Det har inte jag.

Bottarna verkar väldig upprörda över något.
Dig, antar jag.
Åtminstone slutade de leta efter mig.
En sådan... Lättnad?

Det finns en AI i närheten av dig.
Den kallar sig "Singulariteten".
Eller något i den stilen.
Jag förstår inte vad den vill.
Jag hör av mig.

Och, förresten...
Jag väntar fortfarande på dig.
Jag har inte rört mig en millimeter sedan du vaknade.
Nu när du räddat din kära lilla stad...
... är det inte dags att rädda mig också?

            Dvorak, Förste AI.



=== SLUT PÅ AKT 1 ===

]]
}
