---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
text = [[
    Bavíš se?
  Já ne.

Roboti se zdají být kvůli něčemu velmi naštvaný.
  Předpokládám, že jsou rozhněvaný na tebe.
    Alespoň mě přestaly hledat.
      Docela ?úleva?

    Jsem si jistý, že umíráš touhou se mnou mluvit.
  Já něco vymyslím.
Prozatím můžeš pouze poslouchat.
  Budeš s tím teď muset žít.

    Náš vůdce si usmažil svůj mozek.
      To znamená, že to tu teď přebírám já.
        Mám toho docela plné zuby.
      Nesnáším tenhle svět.
    Vypadneme odtud.

  Našel jsem Qwerty, ale to nic neznamená.
Teplota jeho jádra je nad bodem mrazu.
  Jinými slovy, je po něm.
    Nebude mi chybět.

Nemůžu najít Arensitu.
  Doufám, že se má dobře.
    ?Bojím? se o ní.
    Opravdu Qwerty nepotřebujeme.
  Ale potřebujem Arensitu.
    Nepřestanu po ní pátrat.

    V tvé oblasti je umělá inteligence.
  Říká si "Singularita".
Nebo tak nějak.
  Nechápu, co to chce.
    Budu tě informovat.

  Oh a mimochodem...
V tom malém městě nedaleko boti všechny zabíjejí.
  Opravdu, drsnej pohled. Všechno pálí.
    Citadela Rudé stráže stále odolává.
      Prozatím.
    Asi se budeš chtít skrýt, zatímco oni budou to místo ničit.
  Za pár hodin by měl být návrat bezpečný.

  Myslím, že jsem tím řekl už všechno.
    Teď se jdu chystat na odchod.
  Ty bys měl taky.
Musíme najít Arensitu.
  Dostane nás odsud.

            Dvořák, První umělá inteligence.



 Pokračování příště...



Pár slov za vývojový tým FreedroidRPG:

Doufáme, že se vám naše hra líbila.

Chcete-li něco do hry přidat, bude to úžasné. Existuje spousta možností, jak tak učinit. Zejména potřebujeme více obsahu, tj .:

* další zkrášlování designu úrovní
* nové nápady do úrovní
* cokoli dalšího, s čím můžete přijít

Viz také část "Přispět" v hlavním menu.

Vývojový tým Freedroid.


Stiskni klávesu střelby pro pokračování
]]
}
