---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--  Copyright (c) 2003 Pete Spicer
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
text = [[
            STEUERUNG

BEWEGUNG:

Das Spiel wird überwiegend mit der Maus gesteuert. Klicke mit der linken Maustaste auf die Stelle, zu der du dich bewegen willst. Halte die linke Maustaste, um weiter in die gezeigte Richtung zu laufen. Halte beim Laufen die Steuerungstaste (STRG/CTRL) gedrückt, um zu Rennen. 

ANGRIFF:

Klicke mit der linken Maustaste auf einen Gegner, damit Tux ihn mit seiner aktuell ausgerüsteten Waffe angreift. Trägt Tux eine Feuerwaffe bei sich, wird er den Gegner aus sicherem Abstand beschießen. Sollte der Gegner nicht in Reichweite sein, bewegt sich Tux automatisch auf ihn zu, bis er erledigt ist.

SPEZIELLE FUNKTIONEN:

Klicke mit der rechten Maustaste, um die aktuell gewählte Fähigkeit/ das aktuelle Programm zu verwenden.

Standardbelegung (kann innerhalb des Spiels mit der Taste F1 geändert werden)

  Escape … Zeige das Hauptmenü
  F1 … Zeige die aktuelle Tastenbelegung
  F2 … Vollbildmodus (nur für Linux-Distributionen)
  F3 … Schnellspeichern
  F4 … Schnellladen
  F5-F12 … Schnellwahl Programm 1 bis 8

  I … Inventar anzeigen
  C … Charakterdaten anzeigen
  S … Fähigkeiten/Programme anzeigen
  Leertaste … Alle offenen Anzeigen schließen
  Q … Aufgaben anzeigen
  0-9 … Schnellinventar - Gegenstände 0-9 einsetzen

  P ... Pause
  A halten … Stehen bleiben beim Angriff (nur für Fernkampf)
  Shift halten … Bewegen, während man auf das letzte Ziel weiter schießt
  Tab … Autokarte anzeigen

  R … Waffe nachladen
  Strg/Ctrl halten … Rennen
  U … Immer rennen aktivieren/deaktivieren

  X halten … Kurzzeitig Gegenstandsnamen anzeigen
  Z … Dauerhaft Gegenstandsnamen anzeigen
  T … Wände durchsichtig machen, wenn Tux dahinter steht (nur OpenGL-Modus)

ÜBERNAHME/REDEN

Um mit einem freundlichen Droiden zu reden, klicke mit der linken Maustaste auf ihn. Um einen feindlichen Roboter zu übernehmen, lege die Übernahme-Fähigkeit aus dem Fähigkeitsmenü an und klicke danach mit der rechten Maustaste auf den Roboter.

Beim darauf folgenden Minispiel können das Mausrad oder die Richtungstasten benutzt werden.

Es ist empfehlenswert, im Hauptmenü die Einführung zu benutzen, um die genaue Spielweise zu erfahren.

Wer weitere Hilfe benötigt, kann den Chat-Kanal #freedroid auf irc.libera.chat besuchen und höflich fragen. Achtung: Nur auf Englisch!

Das war's auch schon. Fröhliches Zocken!



Drücke die linke Maustaste, um das Spiel zu starten.
]]
}
