-- Comments after the NPC names are meant to declare alternative i18n'd names
-- those will be set in dialog scripts (via a call to set_bot_name()).
-- Those declarations are currently needed, here, due to the separation between
-- the translation domains of dialog and config files.

-- Comments after the NPC names are meant to declare alternative i18n'd names
-- those will be set in dialog scripts (via a call to set_bot_name()).
-- Those declarations are currently needed, here, due to the separation between
-- the translation domains of dialog and config files.
npc_list{
	"Terminal",              --[[TRM]]--
	"AfterTakeover"
	}

--[[
npc_shop{
name = "Dummy",
items = {
	 {"Big kitchen knife"},
	 {"Normal Jacket", 2}
	}
}
]]--
