---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
text = [[
            Редактор уровней FREEDROIDRPG

=== ВВЕДЕНИЕ ===

FreedroidRPG поставляется со встроенным редактором уровней. Редактор позволяет вам управлять любой частью обычной карты и сохранять карты.

Вы можете получить к нему доступ из главного меню, нажав «Редактор уровней», или выполнить «freedroidRPG -e».

    --- Подсказки ---
Для включения-выключения всплывающих при наведении мыши подсказок интерфейса, щёлкните значок с белым пузырьком речи, расположенный возле правого края окна в нижнем ряду кнопок.

    --- Краткая информация ---
Краткая информация о препятствиях и предметах будет появляться, если щёлкнуть по ним правой кнопкой мыши в верхней панели выбора объектов.

    --- Навигация ---
Чтобы изменить текущий уровень щёлкните номер соседнего уровня на миникарте в правом нижнем углу или выберите нужный уровень в меню редактора (см. ниже).

    --- Редактирование карты ---
Всего четыре режима редактирования: редактирование препятствий, редактирование пола, редактирование предметов, правка путей.

Кнопка, выбранная в левом нижнем углу, указывает объекты, которые можно выбрать или разместить.
Когда кнопка выбрана, и вы находитесь в режиме размещения, объект, который вы разместите, отображается лентой в верхней части экрана. Выделение на ленте разделено вкладками непосредственно под ней.

Вы можете выбрать тип препятствия, который вы хотите разместить на карте в верхнем селекторе объектов. Просто нажмите на него, чтобы выбрать. Препятствия разделены на группы, чтобы обеспечить лучший обзор.

Нажав пробел, вы войдете в режим выбора, на который указывает изменение курсора. Можно выбрать только группу объектов, представленных текущим активированным режимом объектов.
Важное примечание: вы сможете выбрать только те вещи, которые включены в текущий выбранный режим. Если вы находитесь в режиме препятствий, вы не сможете выбрать элементы или плитки пола.


        Режим редактирования препятствий:

Для того, чтобы выбрать этот режим, нажмите на кнопку, селектора категории на левой нижней области, которая помечена 'препятствие'.
Выбрав препятствие, просто нажмите где-нибудь на карте, чтобы поместить его в местоположение курсора.
Поскольку щелчок немного неточен, вы также можете использовать свою цифровую панель для размещения препятствий.
Нажмите на крайнюю левую (она показывает небольшую сетку) из пяти кнопок над селектором категорий, чтобы получить сетку с отображаемыми номерами. Используйте щелчок левой кнопкой мыши для включения и выключения сетки и щелкните правой кнопкой мыши для изменения режима сетки.
Эти цифры относятся к номерам вашей цифровой панели, если она у вас есть. Нажатие кнопки '1 ' поместит препятствие, выделенное в селекторе объектов, в место помеченное '1' на фиолетовой сетке.
Поскольку размещение линии стен таким образом довольно неэффективно, вы можете просто удерживать левую кнопку мыши, и линия стен будет помещена при перемещении курсора, если у вас выбран объект стены. Это работает с наиболее распространенными стенами в FreedroidRPG.
Если удерживать левую кнопку мыши и размещать стены, щелчок правой кнопкой мыши удалит все стены, которые вы нарисовали после начала удержания левой кнопки мыши.
Есть некоторые специальные объекты. Стеклянные стены и треснувшие кирпичные стены, а также бочки и ящики могут быть уничтожены несколькими ударами. При этом бочки и ящики могут выбрасывать предметы. Сундуки могут быть открыты и при этом так-же могут выбрасывать предметы.
Символ с перечеркнутыми шагами на самом деле не объект, а чистая и невидимая блокирующая область ('прямоугольник столкновения'). Прямоугольники столкновения являются самой сердцевиной каждого объекта, так как они мешают вам просто проходить через них. Так-же это возможно для путевых точек или напольных плиток.

            Выбор препятствий

Удерживая левую кнопку мыши, вы можете выбрать прямоугольник препятствий. После отпускания кнопки мыши, выбранные препятствия будут окрашены в другой цвет, указывающий, что они выбраны. Чтобы выбрать препятствия, которые не находятся в области такого прямоугольника выбора, удерживайте клавишу "Ctrl" и щелкните препятствие или выберите другой прямоугольник, включайющий их.
Возможно, вы автоматически выбрали несколько препятствий одним щелчком мыши. Вы можете переключаться между выбранными препятствиями, щелкнув значок со стулом и полкой на нем, или нажав "n".
Значок с корзиной позволяет удалить выбранное препятствие.
Вы также можете вырезать (Ctrl+x, также можно использовать для удаления препятствий, просто не вставляя их снова;)), копировать (Ctrl+c) и вставлять (Ctrl+v) вырезанные или скопированые препятствия.
Вы можете перемещать выбранные препятствия, удерживая левую клавишу shift, перетаскивая препятствие. Однако это может быть довольно неточно.

            Размещение объектов в сундуках.

Просто выберите нужный сундук и нажмите самую левую кнопку в верхнем ряду кнопок.
Вы будете перенаправлены на экран, который выглядит как экран магазина.
Там будет отображаться нож (который, кстати, на самом деле не помещается в сундук) выберите его и нажмите на кнопку 'Sell' (продать}.
Выберите элементы, которые должны выпасть, когда игрок открывает сундук.
Эти элементы будут отображаться в верхней панели магазина.
Для того, чтобы удалить один из этих пунктов, просто выберите его и нажмите на кнопку 'Buy' (купить).
Нажатие на красный крестик позволит вам выйти из этого экрана.

            Добавление текста на указатель.

Выберите знак и добавьте метку препятствия с текстом знака. Сохраните карту и выйдите.
Откройте файл уровня (карта / уровни.dat) и найти новую метку препятствия. Измените строку над текстом с 'type=30' на 'type=32' и сохраните.
Теперь при нажатии на кнопку входа в игру появится ваше короткое сообщение.

            Добавление диалога в терминал

Выберите терминал и добавьте метку препятствия с именем диалогового окна, которое вы хотите использовать. Сохраните карту и выйдите.
Откройте файл уровня (карта / уровни.dat) и найти новую метку препятствия.
Измените строку над текстом с 'type=30' на 'type=32' и сохраните. Теперь при нажатии на терминал в игре он начнет диалог, который вы выбрали.

        Режим редактирования пола:

Режим редактирования пола работает аналогично режиму редактирования препятствий. В селекторе объектов можно выбрать различные типы этажей.
Чтобы заполнить область одной плиткой пола, сначала выберите плитку для использования, затем нажмите и перетащите левую кнопку мыши, пока она не покроет нужную область. Напольная плитка укладывается на текущий слой пола.
Нет полов, которые являются особенными в любом случае, они являются чистым украшением.

Видимость слоев пола можно регулировать с помощью кнопки со значком слоя. Кнопка отображается только для уровней с многослойными полами.
Щелкните левой кнопкой мыши на кнопке переключения между отображением одного слоя и отображением всех слоев. Щелчок правой кнопкой мыши по кнопке изменяет текущий слой пола.

            Выбор типов полов

Выбор так же прост, как в режиме препятствия. Плитки пола можно передвигать методом, который описан выше для препятствий.
Для уровней с многослойными полами выбираются только видимые слои пола. Когда виден один слой пола, выбираются только плитки в текущем слое пола.

Чтобы посмотреть только на пол, нажмите на значок лампы, чтобы не было никаких препятствий. Еще один щелчок позволит снова отобразить препятствия.
Значок с бирюзовым прямоугольником отображает прямоугольники столкновений. Этими прямоуголниками обозначенаблокирующая область препятствия. Такс не может ходить по этому месту.
Если вы включите его и запустите игровое тестирование (об этом режим будет рассказано позже) свей карты, прямоугольники по-прежнему будут отображаться, если они активированы, что очень полезно для проверки того, может ли игрок пройти это место или нет.

        Режим редактирования предметов:

Вы также можете разместить на карте предметы, которые будут использоваться игроком.
Предметы - это объекты, которые игрок может забрать. Их можно носить с собой, некоторые даже использовать или надеть.
Некоторые предметы используются для продвижения по сюжету, другие предоставляют бонусы игроку, а третьи вообще ничего не делают.
Выберите режим предметов и нажмите на элемент, отображаемый в селекторе объектов. Для некоторых предметов перед их размещением необходимо указать количество.
Вы можете установить его, нажимая кнопки со стрелками или перетащив синий шар влево или вправо.
Нажмите 'g', чтобы лучше рассмотреть, какие элементы доступны (также может быть использован для установки предмета, он будет поставлен на перекрестье). Нажмите 'Esc', чтобы прервать процесс без установки предметов.
Для отмены можно также щелкнуть значок с перечеркнутыми ботинками.


        Режим правки путей:

В настоящее время дроиды (то есть все неигровые персонажи) перемещаются по уровням, используя предопределенные путевые точки.
Чтобы установить путевую точку, нажмите клавишу "w". Это переключит путевую точку на прямоугольнике под перекрестием.
Вы также можете щелкнуть карту в том месте, где вы хотите, чтобы в этом режиме была активирована путевая точка. Другой щелчок где-то еще устанавливает другую путевую точку и автоматически соединяет с ней предыдущую выбранную.
Нажатие на уже существующую путевую точку позволяет подключить ее к другой (просто нажмите на другую, чтобы сделать это).
Однако есть разница между этими двумя методами установки путевых точек. При подключении двух путевых точек с помощью клавиатуры соединения будут однонаправленными.
Это означает, что при подключении из путевой точки A в путевую точку B бот сможет ходить только от A до B, но не обратно.
Вы можете удалить однонаправленное соединение, "перекрыв" его другим, идущим в том же направлении, что и тот, который вы хотите удалить (это не работает с двунаправленными соединениями!).
Однако двунаправленные соединения создаются автоматически с помощью нажатия клавиши мыши для подключения путевых точек.
Важное примечание: невозможно соединить друг с другом путевые точки, находящиеся на разных картах!
Путевые точки также используются для размещения случайно спаунящихся ботов. Однако это может быть неуместно для некоторых путевых точек.
'Нормальные' белые точки преднозначены для спауна ботов, 'специальные' фиолетовые - для НПС.
Вы можете выбрать эти различные типы путевых точек в верхней панели выбора. Чтобы превратить обычную маршрутную точку в фиолетовую или обратно, нажмите shift+w.
Убедитесь, что пути между путевыми точками не заблокированы препятствиями.
Чтобы автоматически проверить всю карту для этого, вы можете использовать валидатор уровня карты, о котором будет рассказано ниже.


        Установка меток:

Существует два вида табличек: метки карт и метки препятствий.
Убедитесь, что каждый идентификатор метки уникален.
Назначение пустой строки ID приведет к удалению соответствующей метки.


            Установка меток карты

Метки карты используются для определения начальных местоположений НПС (см. ReturnOfTux.droids), для задания событий, которые происходят, когда Tux перемещается по ним (см. events.dat), или локаций, для перемещения НПС посредством файлов сценариев lua (события, квесты и диалоги).
Чтобы определить новую метку карты, нажмите клавишу 'm' на клавиатуре или нажмите кнопку с надписью 'M' на ней. Вам будет предложено ввести метку карты. Обратите внимание, что на любой плитке карты, снабженной меткой карты, появится красочный круг.
Метка карты будет автоматически установлена на плитку в середине экрана.
Вы можете включить или выключить отображение дроидов/НПС, нажав кнопку с ботом 302 на ней.

            Установка меток препятствий

Метки препятствий важны, так как некоторые препятствия могут быть отмечены для событий (например, во время квеста). Если, например, предполагается, что событие устраняет специальное препятствие стены, то этому препятствию сначала должно быть дано имя или идентификатор, поэтому оно может быть упомянуто позже в определении события.
Вы также можете использовать их, чтобы добавить диалоги к препятствиям, так что вы можете говорить с ними, как если бы они были NPC.
Чтобы разместить метку на препятствии, необходимо сначала пометить это препятствие (см. описание режима препятствий выше).
При нажатии на значок со знаком и буквой O на нем вам будет предложено прикрепить новую метку к этому препятствию.

Вы можете переключать отображение меток карты с помощью небольшого значка с меткой-кругом на нем.

        Сохранение карт:

Для того, чтобы сохранить карту, нажмите на значок диска в верхней правой части окна редактора. Значок двери позволяет выйти из редактора.
Вы также можете сделать это через меню, которое открывается нажатием клавиши 'Esc'.


Общие советы:

	Изменение обзора
Чтобы изменить коэффициент масштабирования, нажмите клавишу " o " или щелкните значок с увеличительным стеклом на нем.
Попробуйте щелкнуть левой и правой кнопкой мыши, чтобы получить доступ к различным коэффициентам масштабирования.


	Меню редактора

Вы можете получить доступ к этому меню, нажав Esc.

		'Уровень:'
Здесь вы можете легко перейти на другие уровни. Вы можете использовать клавиши со стрелками, если выбран этот пункт
для того чтобы перейти на следующий или предыдущий (по номеру) уровень, или, нажав на нужный уровень, или введя номер нужного уровня и нажав enter.

		Настройки уровня
				Уровень: см. объяснение выше.
				Наименование: название карты отображается на GPS в правом верхнем углу игрового экрана. Вы можете отключить GPS в игре с помощью меню 'параметры'.
				Размер:  вы можете увеличить или уменьшить размер вашего уровня. Выберите нужный край, где вы хотите добавить/удалить линию плиток и нажмите кнопки со стрелками <- or ->.
				Слои пола: чтобы изменить количество слоев пола для текущего уровня, используйте кнопки со стрелками <- or ->.
				Интерфейс края: здесь вы можете установить уровни, которые должны быть рядом с текущим уровнем. Введите номер уровня для соответствующего края.
								У уровня может быть только один смежный уровень (тот, с которым он соприкасается краем) в каждом из четырех основных направлений (Север, Юг, Запад, Восток).
				Случайное подземелье: если вы установите этот параметр в 'Да', игра автоматически создаст подземелье. Вы можете устанавить количество телепортов на карту и с карты с помощью соответствующей опции.
								Случайно сгенерированные подземелья автоматически будут иметь все необходимое, как путевые точки, ботов и препятствия.
				Класс выбрасываемых предметов для препятствий: набор предметов класса предметов, выбрасываемых бочками/сундуками/ящиками.
				Блокада телепорта: разрешает/запрещает телепортироваться от уровня.
				Парный телепорт: это важно, если вы делаете подземелье, которое непосредственно не связано с другой картой. Здесь вы можете установить количество выходов и входов для случайно сгенерированного подземелья.
				Свет: сколько света вам нужно? Нажмите пробел, чтобы переключиться между окружающим (общая яркость настоящей карты) и бонусным (свет, излучаемый некоторыми препятствиями, такими как лампы или грибы) режимом.
				Фоновая музыка: Здесь вы можете установить музыкальную дорожку для воспроизведения, в то время пока игрок ходит по карте. Возможные звуковые дорожки можно найти внутри ./ звук / музыка/.
									 Просто введите имя файла в том числе расширение .ogg.
				Бесконечная выносливость при беге: если у вас установлено значение 'да', выносливость Tux не уменьшится во время бега по карте. Это должно использоваться только в том случае, если на уровне нет враждебных NPC, например, на уровне 0, в городе.
				добавить/удалить уровень: позволяет добавить новый уровень или удалить текущий уровень.

		Расширенные настройки
Здесь вы можете запустить валидатор уровня карты
Валидатор уровня карты проверяет все пути между соединенными путевыми точками, чтобы убедиться, что они не заблокированы препятствиями. Более подробный вывод данных, объясняющих, какие пути заблокированы, можно найти в терминале, когда игра запускается с его помощью, или в глобальном файле вывода ошибок.
Он также может проверить, есть ли у вас критически важные препятствия вблизи границ карты.
Валидатор нужно запускать всегда перед завершением вызова карты.
Запуск 'freedroidRPG -b leveltest' также выполняет эту проверку.

		Игровое тестирование карты
Позволяет легко провести игровой тест ваших модификаций.
После выхода из этого режима, изменения препятствий, которые были сделаны во время игры, например, уничтожение ящиков, будут возвращены к тому времени, когда вы начали тестирование.




Горячие клавиши:
пробел					переключение режима установки/выбора
w						установить метку пути
shift+w					переключение режима для путевых точек на между 'случайный бот' или NPC
escape					доступ к меню
боковые цифровые клавиши 1-9	используется для установки препятствий в соответствующих положениях сетки
n						циклический перебор выбранных препятствий (далее)
z						отмена последнего действия
y						повторить последнее отмененное действие
с						установление пути между точками пути
ctrl+x или backspace		 вырезать выбранные объекты, можно использованы для удаления объектов, без вставки в дальнейшем
ctrl+c					копирование выбранных объектов
ctrl+v					вставка вырезанных/скопированных объектов
alt+shift				перетаскивание выбранных объектов с помощью мыши
клавиши курсора				прокручивание карты
ctrl+стрелки курсора			прокручивание карты большими шагами
колесико мыши				прокручивание в селекторе объектов
ctrl+pageup/page down	прокручивание в селекторе объектов
g						переключение в экран размещения предметов
t						переключение прозрачности в области 3х3 вокруг курсора
m						добавление/редактирование метки в позиции выбранной плитки
o						увеличение
tab						переключение к следующему режиму редактирования
shift+tab				переключение к предыдущему режиму редактирования
f						переключение к следующей закладке объекта
shift+f						переключение к предыдущей закладке объекта


Если у вас возникли проблемы с редактором, пожалуйста, свяжитесь с нами.
 Кроме того, не бойтесь присылать нам карты, если вы сделали что-то крутое, мы не кусаемся. :)
]]
}
