---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
voice_acting = "StartOfGame.ogg",
preroll_text = 3,
postroll_text = 3,
text = [[
What a great day.
Yes, I'm being sarcastic again.
The whole planet is in flames.
Thousands of people are very dead.
Qwerty and Arensito are not responding.

Ah, yes, I almost forgot.
The bloody bots are about to find me, too.
I'm not very happy with that, Not happy at all.
I guess I have to pretend I'm just a nice rock, yet again.
Don't you think it would be a great time to wake up?
Get up. Get here. Save my ass.
Please.

            Dvorak, First AI
]]
}
