---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
voice_acting = "EndOfAct.ogg",
preroll_text = 2,
postroll_text = 5,
text = [[
    ¿Te diviertes?
  No lo soy.

Parece que los bots están muy cabreados por lo que sea.
Supongo que están enfadados contigo.
Al menos dejaron de venir a por mi.
Menudo alivio.

Hay una IA en tu región.
"Singularidad" es como se hace llamar.
O algo así.
No puedo entender lo que quiere.
Te mantendré informado.

Oh, por cierto...
Todavía sigo esperando por ti.
No me he movido un centímetro desde que despertaste.
Ahora que ese querido pueblo tuyo esta a salvo…
¿...No seria un buen tiempo para salvarme a mi también?

            Dvorak, Primera AI.



=== FIN DEL ACTO 1 ===

]]
}
