---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "TheBeginning.ogg",
text = [[
Megpróbálsz meghackelni valaki, ugye?
Nem emlékszel hogy kell?
Buta. Ne égesd ki az agyad, és utána próbáld meg a hackelést.
Itt egy gyorstalpaló, hogy felfrissítsd a memóriád.

Először is, ne próbálj meg hackelni, ha mindjárt meghalsz.
Ha elbuksz, akkor egy szép elektromos kisülést kapsz.
Nem öl meg, hacsak nem sérültél meg csúnyán, de fájni fog.
Sokat.

Két fázisa van a hackelésnek.
Először válaszd ki a legjobbnak gondolt áramköri lapot.
Az egyik sárga, a másik lila.
A választáshoz csak nyomd meg a bal vagy a jobb gombot a billentyűzeten.
Körülbelül 10 másodperced van, mielőtt a bot észrevesz.
Válaszd a lapot, amely szerinted előnyt ad neked.

A második fázis a logikai magok közti kapcsolatok kialakítása.
Ha nem tudnád, azok a dolgok ott középen.

Mivel a botok hibásak, néhány mag a te oldaladon lesz.
Csak néhány támadást indíthatsz, így számítaniuk kell.
Válaszd ki a vezetéket, amellyel megtámadod a magokat.
A le és a fel gombok lenyomásának is működnie kell.
Az egérgörgőt is használhatod.
Ha döntöttél, akkor nyomd meg a szóköz gombot.
Bármi is van a másik oldalon, a vezeték a tiéd lesz.
Persze a bot nem fog ott ülni, mint egy zsák krumpli.
Megpróbálja visszanyerni az irányítást, és kapcsolatokat hoz létre.

Röviddel ezután minden véget ér.
Ha tiéd a legtöbb mag irányítása, akkor a bot a tiéd.
Ha nem, akkor kapsz egy ingyenes áramütést, MegaSys stílusban.

A vezetékezés néha elég őrült a botokban.
A részleteket magadtól kell megtanulnod.
Nem fogom kockáztatni a biztonságomat miattad.
Túl sok bot üzen túl sokáig.

Ó, és egy kérés.
Ha legközelebb úgy döntesz, hogy megsütöd az agyad…
Csak vidd magaddal a leírásokat a stázisalvásba.
Legközelebb lehet hogy nem tudlak megmenteni.

            Dvorak, Első MI.
]]
}
