---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "TheBeginning.ogg",
text = [[
            COMO CONTRIBUIR

FreedroidRPG é um software inteiramente livre, como sua arte.
Ele é desenvolvido exclusivamente por voluntários em seu tempo livre.

FreedroidRPG depende dessas contribuições para ser um jogo melhor.
Se você gostaria de contribuir de algum jeito, mas não sabe como, aqui tem uma lista de coisas:

TESTES E RELATÓRIOS DE ERROS:

Precisamos de pessoas que testem o jogo e relatem qualquer coisa que não funcione corretamente ou parece instável. Isso inclui coisas menores, como erros de grafia. O trabalho de testar está crescendo com o tamanho de FreedroidRPG. Precisamos de sua ajuda.
Não hesite em enviar sugestões!

MAPEAMENTO:

Nós estamos procurando pessoas que possam fazer mapas para nós. Há um editor de mapas embutido no jogo. Experimente-o, e se fizer algo interessante, certifique-se de nos enviar.

DOCUMENTAÇÃO:

Atualmente falta documentação. Nós precisamos de documentação de usuário final relacionada ao jogo e a seu editor de mapas, assim como documentação com foco no desenvolvedor. Habilidade com escrita requerida.

EFEITOS SONOROS:

Nós certamente poderíamos usar alguns efeitos sonoros. Se você quiser contribuir para uma boa causa, nós não vamos dizer não. :)

CONTATO:

Se você gostaria de contribuir em algo ou fornecer algum feedback relativo ao jogo, você pode facilmente entrar em contato com os desenvolvedores. Apenas mande um e-mail para: 
freedroid-discussion@lists.sourceforge.net

Ou, se preferir, você pode aparecer em nosso canal IRC (#freedroid em irc.libera.chat). Todos estão convidados. Traga seus amigos!

Obrigado,

            A equipe de desenvolvimento do FreedroidRPG.
]]
}
