---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
text = [[
¿Te diviertes?
Yo no.

Parece que los bots están hechos unos basiliscos.
Creo que la cosa va contigo.
Por lo menos, a mí ya no me buscan.
¡Se agradece!

Te estarás muriendo de ganas por hablar conmigo.
Ya se me ocurrirá algo para que puedas hacerlo.
Ahora, a escuchar.
Hazte a la idea.

A nuestro jefe le han frito la sesera.
Es decir, ahora mando yo.
Estoy hasta la coronilla.
¡Asco de mundo!
Nos vamos de aquí.

He encontrado a Qwerty, pero no nos sirve.
Su temperatura interior supera el punto de congelación.
Hablando en plata: que está muerto.
¡Hasta nunqui!

No encuentro a Arensito.
Espero que la pobre esté bien.
Me preocupa.
En realidad no necesitamos a Qwerty.
Pero a Arensito sí.
Seguiré buscándola.

Hay una IA en tu región.
Se hace llamar "Singularidad".
O algo así.
No entiendo qué es lo que quiere.
Te mantendré al día.

¡Ah! Por cierto...
Los bots están masacrando el poblado vecino.
¡Un espectáculo! Con todo quemado...
Pero la ciudadela de la Guardia Roja sigue en pie.
Por ahora.
Igual te conviene esconderte mientras lo arrasan todo.
En unas horillas, creo que ya se podrá volver sin peligro.

Creo que con esto ya está todo.
Empiezo ya los preparativos para el viaje.
Empieza tú también.
Hay que encontrar a Arensito,
que es quien nos va a sacar de aquí.

Dvorak, Primera IA.



Continuará...



Mensaje del equipo de desarrollo de FreedroidRPG:

Esperamos que te haya gustado el juego.

Si quieres aportar algo, por nuestra parte, estamos encantados. Hay muchas formas de hacerlo; necesitamos especialmente más contenidos, por ejemplo:

* Embellecimiento del diseño, nivel adicional
* Ideas de nuevo nivel
* Cualquier otro aporte que se te ocurra.

Consulta también la sección "Contribuir".

El equipo de diseño de Freedroid.


Pulsa el botón de disparo para continuar.
]]
}
