---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
text = [[
    Веселишься?
  А я нет.

Боты выглядят чем-то расстроенными.
  Думаю, они на тебя злятся.
    Они хотя бы перестали искать меня.
      Какое «облегчение».

    Уверен, ты до смерти хочешь поговорить со мной.
  Я думаю кое о чём.
Сейчас ты можешь лишь слушать.
  И пока тебе придётся с этим смириться.

    У нашего лидера мозги спеклись.
      Поэтому беру управление на себя.
        Я уже сыт по горло.
      Ненавижу этот мир.
    Мы убираемся отсюда.

  Я нашёл Qwerty, но это ничего не меняет.
Температура его ядра близка к точке замерзания.
  Другими словами, он мёртв.
    Но скучать по нему не буду.

Я не могу найти Arensito.
  Надеюсь, она в порядке.
    Я «переживаю» за неё.
    На самом деле нам не нужен Qwerty.
  Но Arensito нам нужна.
    Я продолжу искать её.

    В твоём регионе есть ИИ.
  Он сам себя называет «Сингулярностью».
Или что-то вроде того.
  Я не понимаю, чего он хочет.
    Буду держать тебя в курсе.

  О, и кстати...
Боты увивают всех подряд в том городишке неподалёку.
  С одного взгляда понятно. Они сжигают всё.
    Цитадель Красной стражи пока держится.
      Пока.
    Возможно, ты захочешь спрятаться, пока они разрушают то место.
  Через несколько часов вернуться туда должно быть безопасно.

  Думаю, больше ничего не забыл.
    Сейчас я начну готовиться к отъезду.
  И ты должен.
Нам нужно найти Arensito.
  Она вытащит нас отсюда.

            Дворак, первый ИИ.



 Продолжение следует...



Слово команды разработчиков FreedroidRPG:

Надеемся, вам понравилась наша игра.

Если вы захотите добавить что-нибудь в игру, будет чудесно. Есть масса возможностей сделать это. Особенно нужно расширить содержание, например:

* разработка дополнительного украшения уровней
* идеи новых уровней
* всё, что вы ещё можете придумать

Также загляните в раздел «Как помочь».

Команда разработчиков FreedroidRPG.


Нажмите «Огонь», чтобы продолжить
]]
}
