---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
text = [[
    Ti stai divertendo?
  Io no.

I robot sembrano molto peturbati da qualcosa.
  Suppongo che sono arrabbiate contro di te.
    Almeno hanno smesso di cercarmi.
      Un bel? sollievo?

    Sono sicuro che stai morendo per parlare con me.
  Penserò a qualcosa.
Per ora puoi solo ascoltare.
  Dovrai convivere con questo adesso.

    Nostro capo ha il cervello fritto.
      Questo significa che ho preso.
        Sono abbastanza stufo.
      Odio questo mondo.
    Stiamo uscendo fuori di qui.

  Ho trovato Qwerty, ma questo non significa nulla.
Sua temperatura interna è quasi al punto di congelamento.
  In altre parole, è morto.
    Non mi mancherà, lui.

Non riesco a trovare Arensito.
  Spero che lei sta bene.
    Io sono? preoccupato? su di lei.
    Non abbiamo davvero bisogno Qwerty.
  Ma abbiamo bisogno di Arensito.
    Devo continuare a cercarla.

    C'è un'Intelligenza Artificiale nella tua regione.
  Si è chiamata "Singolarità".
O qualcosa di simile.
  Non riesco a capire ciò che vuole.
    Ti terrò informato.

  Oh a proposito...
I robot stano uccidendo tutti in quella piccola città nelle vicinanze.
  Davvero, piuttosto uno spettacolo. Stanno bruciando tutto.
    La di Guardia Rossa della Cittadella è ancora in grado.
      Per ora.
    Si potrebbe voler nascondere mentre distruggono il posto.
  In poche ore potrebbe andarci di nuovo in sicuro.

  Penso che ho detto tutto.
    Devo iniziare i preparativi per la partenza adesso.
  Così si dovrebbe.
Abbiamo bisogno di trovare Arensito.
  Lei otterrà noi da qui.

            Dvorak, primi IA.



 Da continuare...



Ancora una cosa da FreedroidRPG development team:

Speriamo che ti sia piaciuto il nostro gioco.

Se si desidera aggiungere qualcosa al gioco, sarebbe meraviglioso. Ci sono un sacco di opportunità per farlo. Abbiamo bisogno soprattutto più contenuti, vale a dire:

* abbellimento aggiuntivo del disegno di livello
* nuove idee di livello
* qualsiasi altra cosa che si puoi trovare

Vedi anche la sezione 'Contribute'.

The freedroid development team.


Premi il tasto Fire per continuare
]]
}
