---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "TheBeginning.ogg",
text = [[
Se snažíš do někoho nabourat, co?
A nepamatuješ si jak na to?
Hlupáku. Nejdřív přestaň smažit svůj mozek a pak běž hackovat.
Zde je pro osvěžení tvé paměti rychlokurz.

Za prvé, nesnaž se hackovat, když máš málo života.
Pokud selžeš, dostaneš pěknej elektrickej šok.
Ten tě nezabije, pokud ti zbývá dostatek života, ale bude to bolet.
Hodně.

Jsou dvě fáze hackování.
V první fázi si nejprve vyber obvodovou desku, kterou považuješ za nejlepší.
Jedna je žlutá, ta druhá fialová.
Pro výběr stačí na klávesnici stisknout směr vlevo nebo vpravo.
Máš k dispozici okolo 10ti vteřin, než si tě robot všimne.
Vyber si desku, která ti dá podle tebe větší výhodu.

V druhé fázi provádíš propojení logických uzlů.
Pro případ, že netušíš, která bije, to jsou ty věci uprostřed.

Vzhledem k tomu, že roboti mají chyby, jsou některé uzly na tvé straně.
Můžeš provést jen několik útoků, tak si je dobře spočítej.
Vyber si drát, který chceš použít k útoku na uzel.
Toho docílíš opakovaným stisknutím klávesy pro pohyb nahoru a dolů.
Můžeš také použít kolečko myši, pokud ji máš.
Pokud jsi již učinil rozhodnutí v tahu, stiskni mezerník.
Cokoli je na druhé straně drátu, bude to tvé.
Samozřejmě, robot tam nebude jen tak přiblbě sedět.
Bude se snažit znovu získat kontrolu a i on bude vytvářet spojení.

Po krátké době bude po všem.
Pokud v tom okamžiku budeš mít kontrolu nad větším počtem uzlů, bot ti bude patřit.
Pokud ne, zdarma dostaneš elektrickým proudem ve stylu MegaSysu.

Občas je vnitřní zapojení robotů docela šílené.
Detaily se budeš muset naučit sám.
Pro tvé pohodlí nebudu riskovat svou bezpečnost.
Je zde příliš mnoho robotů na to, abych udržoval přenos aktivní příliš dlouho.

Oh, a prosba.
Až se zase příště rozhodneš usmažit si mozek...
Vem si s sebou do stázového spánku nějaké ty příručky.
Až zase budeš potřebovat zachránit, nemusím tu příště být.

            Dvořák, První umělá inteligence.
]]
}
