---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
text = [[
             FreedroidRPG 1.0

PROGRAMAÇÃO: 

        Samuel Degrande
         Christoph Franzen
        Scott Furry
        Arthur Huillet
        Gregory Lozet
        lumidify
        specing
        Stefan Kangas
        Xenux

CONTEÚDO DO JOGO:

        alex
         Kunjappu Abhijith
         DroidBotAI
         Rafael Fontenelle
         can-ned_food
        Scott Furry
         Robin Gareus
        Infrared
        Matthias Krüger
        Richard Lightman
        Miles McCammon
        Jonatas L. Nogueira
        pekpek
         Sydney
         wlan2

GRÁFICOS:

        Infrared
        Bastian Salmela

MÚSICA:

         girix8
        pekpek

SFX:

        pekpek

TRADUÇÕES:

        Tcheco (cs):
          Jan Tojnar
          Zdenek Chmelar

        Alemão (de_DE):
          JM Franz
          Matthias Krüger
          lumidify
          Link Mario

         es:
          Pedro Arana
           Carlos Daniel Landin Montaperto
          Luisi Nogueira
          Dani Quiroz
           Lua Marchante Tello
          Valora Valenteno

        Francês (fr_FR):
          Sebastian Adam
          Alérion
           Benjamin Bertrand
          Stevens D.
          Samuel Degrande
          Nicolas Fargier
          Benjamin Leduc
          Duong Khang Nguyen
          syl_
          Xenux

         hu:
           Balazs Mesko

         it:
           ginoingras
          Michele Marongiu
           Silvia
           Sebastiano Pistore
          Emanuele Sorce

        Português (pt_BR):
          Anelise D. J.
          Luiz Phelipe Ferreira da Silva
           Rafael Fontenelle
          Jonatas L. Nogueira

         ru:
          algan011
          listores
           Rodion
           Roman M. Yagodin

        Sérvio (sv_SV):
          Alexander Forsberg
           Jonatan Nyberg

MISCELÂNEA:

         Julien Puydt



            TAMBÉM, EM VERSÕES ANTERIORES

PROGRAMAÇÃO: 

        Maria Grazia Alastra
        Pedro Arana
        Catalin Badea
        Bob
        Pierre Bourdon
        Bryan C
        Simon Castellan
        Mike Fleischmann
        Jann Horn
        jcoral
        Józef Kucia
        Pavaluca Matei
        Miles McCammon
        Michael Mendelson
        Esa-Matti Mourujarvi
        Ari Mustonen
        Michael Parks
        Nicolas Pepin-Perreault
        Samuel Pitoiset
        Quentin Pradet
        Johannes Prix
        Reinhard Prix
        Alexander Solovets
        Philippe Tetar
        v4hn

CONTEÚDO DO JOGO:

        Amy de Buitléir
        Stefan Huszics
        James
        Raymond Jennings
        Sebastian Offermann
        Kurtis Parramore
        Niklas Spille
        Starminn
        Karol Swietlicki
        rudi_s
        Thor
        JK Wood
 
MÚSICA:

        Nick "Nario" Hagman
        Arvid Picciani
        "O Começo"
            por 4t thieves
        "Daybreak"
            por realsmokers
        "Bleostrada"
            por stud

MISCELÂNEA:

        Mbrola - texto-para-fala
        eSpeak - texto-para-fala
        Ryan 'simcop2387' Voots
        Andrew A. Gill
        Zombie Ryushu
        Ted Cipicchio
        The Doctor
        Eino Keskitalo
        Simon Newton
        Duong Khang Nguyen
        Clint Herron
        Hike Danakian
        Ian Griffiths
        David Kremer
        Armin Winterer
]]
}
