---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "TheBeginning.ogg",
text = [[
Intentando hackear a alguien, ¿eh?
¿No recuerdas cómo hacerlo?
Estúpido. No frías tu cerebro para entonces intentar hackear.
Aquí va un curso intensivo para refrescar tu memoria.

Primero, No intentes hackear si estas a punto de morir.
Si fallas, obtendrás una agradable descarga eléctrica.
No te matará a no ser que estés realmente herido, pero dolerá.
Mucho.

Hay dos fases de hackear.
Primero elije cuál placa de circuitos consideras la mejor.
Una es amarilla y la otra es morada.
Solo presiona izquierda o derecha en tu teclado para elegir.
Tienes unos 10 segundos antes de que el bot se percate de ti.
Elige la placa que creas que te de ventaja.

La segunda fase es hacer conexiones a los núcleos lógicos.
En caso de que te lo preguntes, estos son las cosas en el centro.

Debido a que los bots son defectuosos, algunos núcleos estarán de tu lado.
Puedes hacer solo unos pocos ataques, así que hazlos contar.
Elije el cable con el que quieres atacar a los núcleos.
Presionar arriba y abajo en tu teclado debería bastar.
Puedes también usar la rueda de mouse si tienes una.
Cuando decidas, pulsa la barra espaciadora.
Aquello que esté al otro lado del cable pasará a ser tuyo.
Por supuesto el bot no se limitará a sentarse ahí cual cebolla.
Intentará ganar control y también hará conexiones.

Tras un corto período todo habrá terminado.
Si controlas la mayor cantidad de núcleos en ese momento, el robot te pertenece.
Si no, obtienes una electrocución gratuita, al estilo MegaSys.

El cableado dentro de los robots es bastante loco a veces.
Tendrás que aprender los detalles por tu propia cuenta.
No arriesgaré mi seguridad por tu conveniencia.
Demasiados bots para mantenerme transmitiendo demasiado tiempo.

Oh, y una solicitud.
La próxima vez que decidas sofreír tu cerebro...
Simplemente lleva los manuales a sueño estático contigo.
Podría no estar ahí para salvarte la próxima vez.

            Dvorak, Primera AI.
]]
}
