---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "TheBeginning.ogg",
text = [[
Пытаешься кого-то взломать, да?
Не помнишь, как это делается?
Глупый. Не пытайся взламывать, вскипятив мозг.
Вот экспресс-курс, чтобы освежить тебе память.

Во-первых, не пытайся взламывать, когда при смерти.
Если провалишься, то получишь хороший удар током.
Это не убьёт тебя, если ты ещё не слишком изранен, но будет больно.
Очень.

Взлом осуществляется в два этапа.
Сначала выбери печатную плату, которую посчитаешь лучшей.
Одна жёлтая, другая пурпурная.
Для выбора просто нажми влево или вправо на клавиатуре.
У тебя около 10 секунд до обнаружения ботом.
Выбери плату, которая, по твоему мнению, даст тебе преимущество.

Второй этап — создание подключений к ядрам логики.
Если интересно, это те штуки по центру.

Из-за глючности ботов некоторые ядра будут на твоей стороне.
Ты можешь сделать всего несколько атак, так что рассчитывай ходы.
Выбери соединение для атаки ядра.
Нажатие вверх-вниз на клавиатуре должно работать.
При наличии можешь использовать колесо мыши.
Когда ты принял решение, нажми пробел.
Всё по ту сторону соединения станет твоим.
Естественно, бот тоже не станет сиднем сидеть.
Он также подсоединится и попытается вернуть контроль.

Вскоре всё закончится.
Если ты контролируешь в данный момент большинство ядер, бот твой.
Если нет, тебя ударит током, бесплатно, в стиле Мегасистем.

Соединения внутри ботов временами несколько безумны.
Подробности выяснишь сам.
Я не собираюсь рисковать собственной безопасностью ради твоего удобства.
Слишком много ботов, чтобы поддерживать связь дольше.

И ещё просьба.
В следующий раз, когда решишь спалить мозг...
...возьми с собой в стазис учебники.
В следующий раз меня может не оказаться рядом, чтобы спасти тебя.

            Дворак, первый ИИ.
]]
}
