---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
voice_acting = "StartOfGame.ogg",
preroll_text = 3,
postroll_text = 3,
text = [[
Que ótimo dia.
Sim, estou sendo sarcástico de novo.
O planeta inteiro está em chamas.
Milhares de pessoas estão bem mortas.
Qwerty e Arensito não estão respondendo.

Ah, sim, eu quase esqueci.
Os malditos robôs estão prestes a me encontrar, também.
Não estou muito contente com isso. Nem um pouquinho.
Acho que vou ter de fingir mais uma vez que sou apenas uma pedra interessante.
Não acha que seria uma ótima hora pra você acordar?
Levante-se. Venha até aqui. Salve a minha pele.
Por favor.

            Dvorak, Primeiro IA
]]
}
