---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--  Copyright (c) 2003 Pete Spicer
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
text = [[
            CONTRÔLES

DÉPLACEMENT:

Ce jeu se joue avec la souris. Effectuer un clic sur le sol avec le bouton gauche de la souris pour se déplacer. Garder ce bouton enfoncé afin de continuer à se déplacer dans la même direction. Garder le bouton Ctrl enfoncé fait courir le personnage.

ATTAQUE:

Un clic du bouton gauche de la souris sur un ennemi demandera à Tux de s'en approcher et l'attaquer avec l'arme équipée. Si c'est une arme à feu alors Tux reste sur place et tire sur l'ennemi.

FONCTIONS SPÉCIALES:

Cliquer avec le bouton droit de la souris pour activer les compétences sélectionnées.

Touches par défaut (la plupart des touches peuvent être redéfinies dans le panneau des raccourcis clavier - F1)

  Échap ... Afficher le menu principal
  F1 ... Afficher le panneau des raccourcis clavier
  F2 ... Basculer le mode plein-écran (Linux seulement)
  F3 ... Sauvegarder
  F4 ... Charger
  F5-F12 ... Choisir rapidement les programmes 1 à 8

  I ... Afficher l'inventaire
  C ... Afficher le personnage
  S ... Afficher les compétences
  Espace ... Fermer tous les panneaux ouverts
  Q ... L'historique des quêtes
  0-9 ... Utiliser les items 0 à 9 de l'inventaire rapide

  P ... Pause
  Enfoncer A ... Attaquer tout en restant à la même position
  Enfoncer Majuscule ... Garder la cible courante sélectionnée pendant les déplacements
  Tab ... Basculer l'affichage de la carte

  R ... Recharger
  Enfoncer Ctrl ... Courir
  U ... Basculer le mode "toujours courir"

  Enfoncer X ... Afficher la description des items au sol
  Z ... Basculer l'affichage de la description des items au sol
  T ... Basculer la gestion des murs transparents lorsque Tux s'approche (OpenGL seulement)

PIRATAGE/CHAT

Pour parler à un robot amical, il suffit de cliquer dessus. Pour prendre le contrôle un robot hostile, sélectionner la compétence "Piratage" depuis le panneau des compétences et cliquer sur le bouton droit de la souris pour démarrer le piratage.

Pour le jeu de piratage, vous pouvez utiliser la molette de la souris ou les touches directionnelles du clavier.

Vous pourriez être intéressé par le tutoriel accessible depuis le menu principal.

Si vous êtes coincé et avez besoin d'aide, n'hésitez pas à vous connecter sur #freedroid chez irc.libera.chat pour demander de l'aide.

C'est tout, bon jeu.



Cliquer sur le bouton gauche de la souris pour commencer à jouer.
]]
}
