---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
voice_acting = "StartOfGame.ogg",
preroll_text = 3,
postroll_text = 3,
text = [[
Was für ein großartiger Tag.
Ja, ich bin mal wieder sarkastisch.
Der ganze Planet steht in Flammen.
Tausende Leute sind bereits hinüber.
Qwerty und Arensito antworten nicht.

Ach ja, fast vergessen.
Die blutrünstigen Blechbüchsen sind auch mir auf den Fersen.
Das gefällt mir nicht, ganz und gar nicht.
Ich glaube, ich sollte mich mal wieder als Felsen ausgeben.
Wäre das nicht die Gelegenheit um aufzuwachen?
Steh auf. Komm her. Rette mich, verdammt!
Bitte.

            Dvorak, die erste KI
]]
}
