---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "TheBeginning.ogg",
text = [[
Cerci di incidere qualcuno, eh?
Non ti ricordi come farlo?
Idiota. Non surriscaldare il tuo cervello prima di provare lo hack.
Si tratta di un corso rapido per rinfrescarti la memoria.

In primo tempo, non fare tentativo di hack se stai morendo.
Se perdi, riceverai un bello elettro-choc.
Non ti uccidera a meno che non sei quasi morto, ma ti farà male.
Molto male.

Ci sono due fasi di hacking.
In primo tempoo scegli il circuito che ti sempra di essere il migliore.
Uno è giallo e l'altro è viola.
Basta premere sinistra o destra sulla tastiera per scegliere.
Hai circa 10 secondi prima che il robot si accorge.
Scegli il circuito che pensi che ti dà un vantaggio.

La seconda fase è di creare connessioni nei processori.
Nel caso in cui ti stai chiedendo cosa è, sono le cose nel centro.

Perché i bot sono pazzi, alcuni core saràno dalla tua parte.
Si può fare solo pochi attacchi, quindi farli bene.
Scegliere il filo che desidera utilizzare per attaccare i processori.
Premendo su e giù sulla tastiera dovrebbe funzionare.
È inoltre possibile utilizzare la rotellina del mouse se ne hai una.
Come ti sei deciso, premere il tasto spazio.
Tutto ciò che è da altra parte del filo diventerà tuo.
Naturalmente il robot non rimanera li' come una cipolla.
Cercherà di riprendere il controllo e creare sue connessioni.

Dopo un breve periodo tutto sarà finito.
Se è possibile controllare il maggior parte dei nuclei in questo momento, il robot ti appartiene.
In caso contrario, avrai una folgorazione gratis, stilo MegaSys.

Il cablaggio all'interno del robot è a volte abbastanza pazzo.
Dovrei imparare i dettagli da solo.
Non vado a rischiare la mia sicurezza per la tua comodità.
Troppi robot intorno a continuare la trasmissione per troppo tempo.

Oh, e una richiesta.
La prossima volta che decidi di farti saltare il cervello...
Basta prendere i manuali in sonno stasi con te.
Potrebbe non essere qui per salvarti la prossima volta.

            Dvorak, prima IA.
]]
}
