---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "HellFortressTwo.ogg",
voice_acting = "GameLost.ogg",
preroll_text = 3,
postroll_text = 3,
text = [[
            Spiel verloren

Versuch es nochmal. Falls du es tust, dann kaufe auch etwas von unseren Sponsoren:

Dr. Wie - "Mächtige, praktische Technologie!"

Kan4dische 4p0th3k3 - "Erstaunlicher Durchbruch der Naturmedizin! 100% super zufriedene Kunden!!!"

Cryonic Solutions - "Nimm den schnellen Weg in die Zukunft mit Cryonic Solutions!"

Future Ballistics - "Jenseits der Ballistik. Future Ballistics."

MegaSystems - "Was wollen sie heute NICHT tun?"

Masternak Abfallbeseitigung - "Wir ZERSTAMPFEN Ihren MÜLL."

Nicholson AG - "Sicherheit mit aller Macht."

Rote Sonne - "Die Nacht ist vorbei: Probier die Morgendämmerung!"



Versuch es nochmal. Klicken zum Fortfahren.
]]
}
